@@ -1,6 +1,6 @@
 count_for() {
   _labelprefix=$1
-  _result=$(grep "^${_labelprefix} " /var/lib/os-prober/labels 2>/dev/null)
+  _result=$(grep "^${_labelprefix} " /var/lib/os-prober/labels 2>/dev/null || true)
 
   if [ -z "$_result" ]; then
     return
@@ -39,3 +39,10 @@ result () {
   log "result:" "$@"
   echo "$@"
 }
+
+# shim to make it easier to use os-prober outside d-i
+if ! type mapdevfs >/dev/null 2>&1; then
+  mapdevfs () {
+    echo "$1"
+  }
+fi
